==> cinepaint-0.21-1.tar.gz: cinepaint-0.21-1/plug-ins/bracketing_to_hdr/gui/AllWindows.hpp <==
/*
 * gui/AllWindows.hpp  --  Part of the CinePaint plug-in "Bracketing_to_HDR"
 *
 * Copyright (c) 2005-2006  Hartmut Sbosny  <hartmut.sbosny@gmx.de>
 *
 * LICENSE:
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
/**
  @file  AllWindows.hpp
   
  Provides a global instance `allWins' holding all top level window instances.
   On this way it allows communication between the top windows: Includes 
   "gui.h" to know the classes declared there and included by "gui.cpp" to
   inform the class implementations (via `allWins.xxx') about the current
   existing top windows.
*/
#ifndef AllWindows_hpp
#define AllWindows_hpp

#include <FL/Fl_File_Chooser.H>
#include "gui.h"
#include "EventTesterWinClass.h"


/**============================================================================
  
  @struct  AllWindows
   
  Collects the pointers of all top level windows respective their wrapper
   classes. Maintains creation, showing, hiding, deleting.
   
==============================================================================*/
struct AllWindows 
{
    MainWinClass * main;
    ResponseWinClass * response;
    FollowUpWinClass * followUp;
    HistogramWinClass * histogram;
    TestSuiteWinClass * testSuite;
    HelpAboutWinClass * helpAbout;
    HelpTutorialWinClass * helpTutorial;
    EventTesterWinClass * eventTester;
    Fl_File_Chooser * fileChooser;
    
    int  main_x, main_y, main_w, main_h;
    int  main_x_def, main_y_def, main_w_def, main_h_def;  // default positions
    
    int  response_x, response_y, response_w, response_h;
    int  response_x_def, response_y_def, response_w_def, response_h_def;
    
    int  followUp_x, followUp_y, followUp_w, followUp_h;
    int  followUp_x_def, followUp_y_def, followUp_w_def, followUp_h_def;
    
    int  histogram_x, histogram_y, histogram_w, histogram_h;
    bool have_saved_pos_histogram;
    
    int  testSuite_x, testSuite_y, testSuite_w, testSuite_h;
    bool have_saved_pos_testSuite;
    
    //  Which (secondary) windows were opened in the last (saved) session?
    bool lastopen_response, lastopen_followUp, lastopen_histogram, lastopen_testSuite;
    
    //  Which (secondary) top windows are to open at start? [Currently unused]
    bool initialopen_response, initialopen_followUp, initialopen_histogram, initialopen_testSuite;
    
        
    AllWindows();
    
    int  run();
    void clear();
    void do_response();
    void do_followUp();
    void do_histogram();
    void do_testSuite();
    void do_helpAbout();
    void do_helpTutorial();
    void do_eventTester();
    
    int  do_file_chooser (            // O - Number of selected files
             const char *value,       // I - Initial path value
             const char *pattern,     // I - Filename patterns
             int        type,         // I - Type of file to select
             const char *title );     // I - Window title string
             
    void grab_win_positions_as_default();
    void evaluate_read_win_positions();
    void reset_win_positions();
    
    void report_lastopen();
};


/**
  Our global instance to collect and maintain the top level windows
*/
extern AllWindows  allWins;

#endif  // AllWindows_hpp

// END OF FILE

==> cinepaint_0.21-2.orig.tar.gz: cinepaint-0.21-2/plug-ins/bracketing_to_hdr/gui/AllWindows.hpp <==
/*
 * AllWindows.hpp  --  Part of the CinePaint plug-in "Bracketing_to_HDR"
 *
 * Copyright (c) 2005-2006  Hartmut Sbosny  <hartmut.sbosny@gmx.de>
 *
 * LICENSE:
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
/**
  @file  AllWindows.hpp
   
  Provides a global instance `allWins' holding all top level window instances.
   On this way it allows communication between the top windows: Includes
   "gui.h" to know the classes declared there and is included by "gui.cpp" to
   inform the class implementations (via `allWins.****') about the current
   existing top windows.
*/
#ifndef AllWindows_hpp
#define AllWindows_hpp

#include <FL/Fl_File_Chooser.H>
#include "gui.h"
#include "EventTesterWinClass.h"

// #include <iostream>
// using std::cout;

/**============================================================================
  
  @struct  AllWindows
   
  Collects the pointers of all top level windows respective their wrapper
   classes. Maintains creation, showing, hiding, deleting.
   
==============================================================================*/
struct AllWindows 
{
    MainWinClass * main;
    ResponseWinClass * response;
    FollowUpWinClass * followUp;
    HistogramWinClass * histogram;
    TestSuiteWinClass * testSuite;
    HelpAboutWinClass * helpAbout;
    HelpTutorialWinClass * helpTutorial;
    EventTesterWinClass * eventTester;
    Fl_File_Chooser * fileChooser;
    
    int  main_x, main_y, main_w, main_h;
    int  main_x_def, main_y_def, main_w_def, main_h_def;  // default positions
    
    int  response_x, response_y, response_w, response_h;
    int  response_x_def, response_y_def, response_w_def, response_h_def;
    
    int  followUp_x, followUp_y, followUp_w, followUp_h;
    int  followUp_x_def, followUp_y_def, followUp_w_def, followUp_h_def;
    
    int  histogram_x, histogram_y, histogram_w, histogram_h;
    bool have_saved_pos_histogram;
    
    int  testSuite_x, testSuite_y, testSuite_w, testSuite_h;
    bool have_saved_pos_testSuite;
    
    //  Which (secondary) windows were opened in the last (saved) session?
    bool lastopen_response, lastopen_followUp, lastopen_histogram, lastopen_testSuite;
    
    //  Which (secondary) top windows are to open at start? [Currently unused]
    bool initialopen_response, initialopen_followUp, initialopen_histogram, initialopen_testSuite;
    
        
    AllWindows();
    
    int  run();
    void clear();
    void do_response();
    void do_followUp();
    void do_histogram();
    void do_testSuite();
    void do_helpAbout();
    void do_helpTutorial();
    void do_eventTester();
    
    int  do_file_chooser (            // O - Number of selected files
             const char *value,       // I - Initial path value
             const char *pattern,     // I - Filename patterns
             int        type,         // I - Type of file to select
             const char *title );     // I - Window title string
             
    void grab_win_positions_as_default();
    void evaluate_read_win_positions();
    void reset_win_positions();
    
    /*  devel & debug helper */
    void report_lastopen();
    
private:
    /*  backup functions for those window wrappers we want to delete (and not only
         to hide) via callback. If needed, window positions could be saved here. */
    static void backup_histogram_(void* I)   {((AllWindows*)I)->backup_histogram_i();}
    void        backup_histogram_i()         {/*cout<<__func__<<"()\n";*/ histogram=0;}
    
    static void backup_testSuite_(void* I)   {((AllWindows*)I)->backup_testSuite_i();}
    void        backup_testSuite_i()         {/*cout<<__func__<<"()\n";*/ testSuite=0;}
    
    static void backup_eventTester_(void* I) {((AllWindows*)I)->backup_eventTester_i();}
    void        backup_eventTester_i()       {/*cout<<__func__<<"()\n";*/ eventTester=0;}
};


/**
  Our global instance to collect and maintain the top level windows
*/
extern AllWindows  allWins;


#endif  // AllWindows_hpp

// END OF FILE
